#!/usr/bin/perl -W

# Assure Conductor config file is updated to support CM-900.
# Should be run via sudo.

($prgnm) = ($0 =~ m,^.*/([^/]+)$,);

sub usage {
	my ($msg) = @_;
	print STDERR $msg . "\n" if ($msg);
	print STDERR <<EOT;
Usage: $prgnm [-d config-dir] [-f config-file]
    -d config-dir   base configuration directory (dflt: /etc/calypso/conductor)
    -f config-file  base configuration file (dflt: config.ini)
EOT
	exit -1;
}

# Defaults
$configDir = '/etc/calypso/conductor';
$configFile = 'config.ini';
$Verbose = 0;

# Process command-line.
while (defined($ARGV[0]) && $ARGV[0] =~ m/^-/) {
	$_ = shift;
	/^-d$/ && ($configDir = shift, next);
	/^-d(.+)/ && ($configDir = $1, next);
	/^-f$/ && ($configFile = shift, next);
	/^-f(.+)/ && ($configFile = $1, next);
	usage(">>Unknown arg: $_");
}
$configDir .= "/" if ($configDir !~ m,/$,);

if (! -d $configDir) {
	print STDERR "Cannot find directory: $configDir\n";
	exit -1;
}
if (! -f "${configDir}$configFile") {
	print STDERR "Cannot find config file: ${configDir}$configFile\n";
	exit -1;
}

# Now open the config-file.
open(CFG, "+<${configDir}$configFile") || die "Cannot open config file: ${configDir}$configFile\n";

# Process the file..
$seen = 0;
@data = ();
while (<CFG>) {
	if (/^\s*CONFIG_VALID_DEVICES\b/) {
		if ($seen) {
			print STDERR "Multiple entries for desired CONFIG setting! (Changes aborted)\n";
			exit(1);
		}
		print STDOUT "FOUND CONFIG_VALID_DEVICES SETTING: $_" if $Verbose;
		if (!/\bCM-900\b/) {
			$_ =~ s/(\S)\s*$/$1,CM-900\n/;
		}
		elsif ($Verbose) {
			print STDOUT "NO CHANGE (setting already present)\n";
		}
		++$seen;
	}
	push(@data, $_);
}
# If file update incomplete, then print 0 and exit.
if (! $seen) {
	push(@data, "\nCONFIG_VALID_DEVICES=CM-3000,CMP-500,SP-2000,CM-800,CM-JUNO,JC-ICR,CM-800i,CM-900\n");
}

# Now replace the original config file with the updated version.
seek(CFG, 0, 0);
print CFG foreach (@data);
close(CFG);

print STDOUT "Update complete.\n";
exit 0;
